@@ -1,5 +1,4 @@
 import numpy as np
 
-
 def nrExtractResources(ind, grid):
-    return grid.ravel(order="F")[ind]
+    return grid.ravel(order='F')[ind]
\ No newline at end of file
