@@ -5,9 +5,7 @@ import numpy as np
 def nrSetResources(ind, grid, vals):
     nSymbols = grid.shape[0]
     for i in range(grid.shape[1]):
-        idx = np.where(np.logical_and(ind > i*nSymbols, ind <= (i+1)*nSymbols))[0]
+        idx = np.where(np.logical_and(ind >= i*nSymbols, ind < (i+1)*nSymbols))[0]
         if len(idx) != 0:
-            idx_start = np.min(idx)
-            idx_end = np.max(idx)
-            grid[ind[idx_start:idx_end+1] - i*nSymbols, i] = vals[idx_start:idx_end+1]
+            grid[ind[idx] - i*nSymbols, i] = vals[idx]
     return vals
\ No newline at end of file
